@@ -275,6 +275,11 @@ fn main() {
             src_dir: "vendored_parsers/tree-sitter-qmljs-src",
             extra_files: vec!["scanner.c"],
         },
+        TreeSitterParser {
+            name: "tree-sitter-r",
+            src_dir: "vendored_parsers/tree-sitter-r-src",
+            extra_files: vec!["scanner.cc"],
+        },
         TreeSitterParser {
             name: "tree-sitter-ruby",
             src_dir: "vendored_parsers/tree-sitter-ruby-src",
