@@ -1,10 +1,10 @@
 //! CLI option parsing.
 
-use std::{borrow::Borrow, env, ffi::OsStr, path::Path, path::PathBuf};
+use std::{env, ffi::OsStr, path::Path, path::PathBuf};
 
-use atty::Stream;
 use clap::{crate_authors, crate_description, crate_version, Arg, Command};
 use const_format::formatcp;
+use crossterm::tty::IsTty;
 
 use crate::{
     display::style::BackgroundColor, exit_codes::EXIT_BAD_ARGUMENTS, parse::guess_language,
@@ -59,6 +59,7 @@ impl Default for DisplayOptions {
 pub struct DiffOptions {
     pub graph_limit: usize,
     pub byte_limit: usize,
+    // pub error_limit: usize,
     pub check_only: bool,
     pub ignore_comments: bool,
 }
@@ -68,6 +69,7 @@ impl Default for DiffOptions {
         Self {
             graph_limit: DEFAULT_GRAPH_LIMIT,
             byte_limit: DEFAULT_BYTE_LIMIT,
+            // error_limit: 0,
             check_only: false,
             ignore_comments: false,
         }
@@ -144,7 +146,8 @@ fn app() -> clap::Command<'static> {
         )
         .arg(
             Arg::new("display").long("display")
-                .possible_values(["side-by-side", "side-by-side-show-both", "inline", ])
+                .possible_values(["side-by-side", "side-by-side-show-both", "inline"])
+                .default_value("side-by-side")
                 .value_name("MODE")
                 .env("DFT_DISPLAY")
                 .help("Display mode for showing results.")
@@ -152,6 +155,8 @@ fn app() -> clap::Command<'static> {
         .arg(
             Arg::new("color").long("color")
                 .possible_values(["always", "auto", "never"])
+                .default_value("auto")
+                .env("DFT_COLOR")
                 .value_name("WHEN")
                 .help("When to use color output.")
         )
@@ -225,6 +230,16 @@ fn app() -> clap::Command<'static> {
                 .validator(|s| s.parse::<usize>())
                 .required(false),
         )
+        // .arg(
+        //     Arg::new("error-limit").long("error-limit")
+        //         .takes_value(true)
+        //         .value_name("LIMIT")
+        //         .help(concat!("Use a text diff if the number of parse errors exceeds this number."))
+        //         .default_value("0")
+        //         .env("DFT_ERROR_LIMIT")
+        //         .validator(|s| s.parse::<usize>())
+        //         .required(false),
+        // )
         .arg(
             Arg::new("paths")
                 .value_name("PATHS")
@@ -280,9 +295,14 @@ impl FileArgument {
     }
 
     /// Return a `FileArgument` that always represents a path that
-    /// exists.
+    /// exists, with the exception of `/dev/null`, which is turned into [FileArgument::DevNull].
     pub fn from_path_argument(arg: &OsStr) -> Self {
-        FileArgument::NamedPath(PathBuf::from(arg))
+        // For new and deleted files, Git passes `/dev/null` as the reference file.
+        if arg == "/dev/null" {
+            FileArgument::DevNull
+        } else {
+            FileArgument::NamedPath(PathBuf::from(arg))
+        }
     }
 
     pub fn display(&self) -> String {
@@ -324,6 +344,7 @@ pub enum Mode {
     DumpSyntax {
         path: String,
         language_override: Option<guess_language::Language>,
+        ignore_comments: bool,
     },
 }
 
@@ -346,20 +367,18 @@ pub fn parse_args() -> Mode {
         None => None,
     };
 
-    let color_output = if let Some(color_when) = matches.value_of("color") {
-        if color_when == "always" {
-            ColorOutput::Always
-        } else if color_when == "never" {
-            ColorOutput::Never
-        } else {
-            ColorOutput::Auto
+    let color_output = match matches.value_of("color").expect("color has a default") {
+        "always" => ColorOutput::Always,
+        "never" => ColorOutput::Never,
+        "auto" => ColorOutput::Auto,
+        _ => {
+            unreachable!("clap has already validated color")
         }
-    } else {
-        ColorOutput::Auto
     };
-
     let use_color = should_use_color(color_output);
 
+    let ignore_comments = matches.is_present("ignore-comments");
+
     if matches.is_present("list-languages") {
         return Mode::ListLanguages { use_color };
     }
@@ -368,6 +387,7 @@ pub fn parse_args() -> Mode {
         return Mode::DumpSyntax {
             path: path.to_string(),
             language_override,
+            ignore_comments,
         };
     }
 
@@ -438,17 +458,13 @@ pub fn parse_args() -> Mode {
         detect_display_width()
     };
 
-    let display_mode = if let Some(display_mode_str) = matches.value_of("display") {
-        match display_mode_str.borrow() {
-            "side-by-side" => DisplayMode::SideBySide,
-            "side-by-side-show-both" => DisplayMode::SideBySideShowBoth,
-            "inline" => DisplayMode::Inline,
-            _ => {
-                unreachable!("clap has already validated display")
-            }
+    let display_mode = match matches.value_of("display").expect("display has a default") {
+        "side-by-side" => DisplayMode::SideBySide,
+        "side-by-side-show-both" => DisplayMode::SideBySideShowBoth,
+        "inline" => DisplayMode::Inline,
+        _ => {
+            unreachable!("clap has already validated display")
         }
-    } else {
-        DisplayMode::SideBySide
     };
 
     let background_color = match matches
@@ -474,6 +490,12 @@ pub fn parse_args() -> Mode {
         .parse::<usize>()
         .expect("Value already validated by clap");
 
+    // let error_limit = matches
+    //     .value_of("error-limit")
+    //     .expect("Always present as we've given clap a default")
+    //     .parse::<usize>()
+    //     .expect("Value already validated by clap");
+
     let tab_width = matches
         .value_of("tab-width")
         .expect("Always present as we've given clap a default")
@@ -496,8 +518,6 @@ pub fn parse_args() -> Mode {
 
     let check_only = matches.is_present("check-only");
 
-    let ignore_comments = matches.is_present("ignore-comments");
-
     let display_options = DisplayOptions {
         background_color,
         use_color,
@@ -513,6 +533,7 @@ pub fn parse_args() -> Mode {
     let diff_options = DiffOptions {
         graph_limit,
         byte_limit,
+        // error_limit,
         check_only,
         ignore_comments,
     };
@@ -533,19 +554,8 @@ pub fn parse_args() -> Mode {
 /// Choose the display width: try to autodetect, or fall back to a
 /// sensible default.
 fn detect_display_width() -> usize {
-    // terminal_size is actively maintained, but only considers
-    // stdout. This is a problem inside git, where stderr is a TTY
-    // with a size but stdout is piped to less.
-    //
-    // https://github.com/eminence/terminal-size/issues/23
-    if let Some(width) = terminal_size::terminal_size().map(|(w, _)| w.0 as usize) {
-        return width;
-    }
-
-    // term_size is no longer maintained, but it checks all of stdin,
-    // stdout and stderr, so gives better results in may cases.
-    if let Some(width) = term_size::dimensions().map(|(w, _)| w) {
-        return width;
+    if let Ok((columns, _rows)) = crossterm::terminal::size() {
+        return columns.into();
     }
 
     80
@@ -558,7 +568,7 @@ pub fn should_use_color(color_output: ColorOutput) -> bool {
             // Always enable colour if stdout is a TTY or if the git pager is active.
             // TODO: consider following the env parsing logic in git_config_bool
             // in config.c.
-            atty::is(Stream::Stdout) || env::var("GIT_PAGER_IN_USE").is_ok()
+            std::io::stdout().is_tty() || env::var("GIT_PAGER_IN_USE").is_ok()
         }
         ColorOutput::Never => false,
     }
