@@ -99,6 +99,7 @@ extern "C" {
     fn tree_sitter_perl() -> ts::Language;
     fn tree_sitter_python() -> ts::Language;
     fn tree_sitter_qmljs() -> ts::Language;
+    fn tree_sitter_r() -> ts::Language;
     fn tree_sitter_ruby() -> ts::Language;
     fn tree_sitter_rust() -> ts::Language;
     fn tree_sitter_scala() -> ts::Language;
@@ -749,6 +750,20 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 sub_languages: vec![],
             }
         }
+        R => {
+            let language = unsafe { tree_sitter_r() };
+            TreeSitterConfig {
+                language,
+                atom_nodes: vec!["string", "special"].into_iter().collect(),
+                delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]")],
+                highlight_query: ts::Query::new(
+                    language,
+                    include_str!("../../vendored_parsers/highlights/r.scm"),
+                )
+                .unwrap(),
+                sub_languages: vec![],
+            }
+        }
         Ruby => {
             let language = unsafe { tree_sitter_ruby() };
             TreeSitterConfig {
@@ -1100,7 +1115,7 @@ pub fn comment_positions(
     let arena = Arena::new();
     let ignore_comments = false;
 
-    let nodes = to_syntax(&tree, src, &arena, config, ignore_comments);
+    let nodes = to_syntax(tree, src, &arena, config, ignore_comments);
     let positions = syntax::comment_positions(&nodes);
 
     positions
@@ -1128,11 +1143,11 @@ pub fn to_syntax<'a>(
         return vec![];
     }
 
-    let highlights = tree_highlights(&tree, src, config);
+    let highlights = tree_highlights(tree, src, config);
 
     // Parse sub-languages, if any, which will be used both for
     // highlighting and for more precise Syntax nodes where applicable.
-    let subtrees = parse_subtrees(src, config, &tree);
+    let subtrees = parse_subtrees(src, config, tree);
 
     let nl_pos = NewlinePositions::from(src);
     let mut cursor = tree.walk();
